@@ -203,8 +203,8 @@ class AmazonSpApi(Client):
             token = self._lock_get_data('grantless_token_', self._get_token, 3000)
         return token['access_token']
 
-    def __init__(self, credentials, is_grantless=False):
-        super(AmazonSpApi, self).__init__(credentials, is_grantless=is_grantless)
+    def __init__(self, credentials, is_grantless=False, region=None):
+        super(AmazonSpApi, self).__init__(credentials, is_grantless=is_grantless, region=region)
         self.boto3_client = boto3.client(
             'sts',
             aws_access_key_id=self.cred.aws_access_key,
